==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/mixin/HoldMyItemsMixin.java <==
package com.zurrtum.create.client.mixin;

import com.holdmylua.source.LuaTestHMI;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.foundation.item.UncontainableBlockItem;
import net.minecraft.class_1306;
import net.minecraft.class_1309;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_759;
import net.minecraft.class_7833;
import net.minecraft.class_7923;
import net.minecraft.class_811;
import net.minecraft.class_918;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import static com.zurrtum.create.Create.MOD_ID;

@Mixin(class_759.class)
public class HoldMyItemsMixin {
    @WrapOperation(method = "renderItem(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/item/ItemStack;Lnet/minecraft/item/ItemDisplayContext;Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;I)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/render/item/ItemRenderer;renderItem(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/item/ItemStack;Lnet/minecraft/item/ItemDisplayContext;Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;Lnet/minecraft/world/World;III)V"))
    private void renderItem(
        class_918 instance,
        class_1309 entity,
        class_1799 stack,
        class_811 displayContext,
        class_4587 matrices,
        class_4597 vertexConsumers,
        class_1937 world,
        int light,
        int overlay,
        int seed,
        Operation<Void> original
    ) {
        class_1792 item = stack.method_7909();
        if (!LuaTestHMI.renderAsBlock.getOrDefault(item.toString(), true) && class_7923.field_41178.method_10221(item).method_12836().equals(MOD_ID)) {
            if (item == AllItems.LINKED_CONTROLLER) {
                displayContext = switch (displayContext) {
                    case field_4323 -> class_811.field_4321;
                    case field_4320 -> class_811.field_4322;
                    default -> displayContext;
                };
                class_310 mc = class_310.method_1551();
                boolean rightHanded = mc.field_1690.method_42552().method_41753() == class_1306.field_6183;
                class_811 mainHand = rightHanded ? class_811.field_4322 : class_811.field_4321;
                class_811 offHand = rightHanded ? class_811.field_4321 : class_811.field_4322;
                boolean noControllerInMain = !mc.field_1724.method_6047().method_31574(AllItems.LINKED_CONTROLLER);
                if (displayContext == mainHand || (displayContext == offHand && noControllerInMain)) {
                    matrices.method_46416(0, 0.1f, 0.1f);
                }
            } else if (item != AllItems.BELT_CONNECTOR && !(item instanceof UncontainableBlockItem)) {
                matrices.method_22907(class_7833.field_40714.rotationDegrees(-75));
                matrices.method_22907(class_7833.field_40718.rotationDegrees(-50));
                matrices.method_22907(class_7833.field_40716.rotationDegrees(-15));
                matrices.method_46416(0.1f, -0.2f, 0.2f);
            }
        }
        original.call(instance, entity, stack, displayContext, matrices, vertexConsumers, world, light, overlay, seed);
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/client/mixin/HoldMyItemsMixin.java <==
package com.zurrtum.create.client.mixin;

import com.holdmylua.source.LuaTestHMI;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.foundation.item.UncontainableBlockItem;
import net.minecraft.class_11659;
import net.minecraft.class_1306;
import net.minecraft.class_1309;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_759;
import net.minecraft.class_7833;
import net.minecraft.class_7923;
import net.minecraft.class_811;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static com.zurrtum.create.Create.MOD_ID;

@Mixin(class_759.class)
public class HoldMyItemsMixin {
    @Inject(method = "renderItem(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/item/ItemStack;Lnet/minecraft/item/ItemDisplayContext;Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/command/OrderedRenderCommandQueue;I)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/render/item/ItemRenderState;render(Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/command/OrderedRenderCommandQueue;III)V"))
    private void renderItem(
        class_1309 entity,
        class_1799 stack,
        class_811 displayContext,
        class_4587 matrices,
        class_11659 queue,
        int light,
        CallbackInfo ci
    ) {
        class_1792 item = stack.method_7909();
        if (!LuaTestHMI.renderAsBlock.getOrDefault(item.toString(), true) && class_7923.field_41178.method_10221(item).method_12836().equals(MOD_ID)) {
            if (item == AllItems.LINKED_CONTROLLER) {
                displayContext = switch (displayContext) {
                    case field_4323 -> class_811.field_4321;
                    case field_4320 -> class_811.field_4322;
                    default -> displayContext;
                };
                class_310 mc = class_310.method_1551();
                boolean rightHanded = mc.field_1690.method_42552().method_41753() == class_1306.field_6183;
                class_811 mainHand = rightHanded ? class_811.field_4322 : class_811.field_4321;
                class_811 offHand = rightHanded ? class_811.field_4321 : class_811.field_4322;
                boolean noControllerInMain = !mc.field_1724.method_6047().method_31574(AllItems.LINKED_CONTROLLER);
                if (displayContext == mainHand || (displayContext == offHand && noControllerInMain)) {
                    matrices.method_46416(0, 0.1f, 0.1f);
                }
            } else if (item != AllItems.BELT_CONNECTOR && !(item instanceof UncontainableBlockItem)) {
                matrices.method_22907(class_7833.field_40714.rotationDegrees(-75));
                matrices.method_22907(class_7833.field_40718.rotationDegrees(-50));
                matrices.method_22907(class_7833.field_40716.rotationDegrees(-15));
                matrices.method_46416(0.1f, -0.2f, 0.2f);
            }
        }
    }
}
